@@ -182,6 +182,9 @@ not_record_ip = None
 push_aligned = None
 not_push_aligned = None
 confirm = None
+timeout = None
+NoSearchResult = None
+SkipRegistrationForm = None
 
 
 def specific_load(input_language, lang_list):
@@ -1203,6 +1206,24 @@ def load(input_lang):
         'Confirm',
     ])
 
+    global timeout
+    timeout = specific_load(input_lang, [
+        '超時',
+        'Timeout',
+    ])
+
+    global NoSearchResult
+    NoSearchResult = specific_load(input_lang, [
+        '沒有搜尋結果',
+        'No Search Result',
+    ])
+
+    global SkipRegistrationForm
+    SkipRegistrationForm = specific_load(input_lang, [
+        '跳過填寫註冊單',
+        'Skip Registration Form',
+    ])
+
     # No changes have been made to any settings
 
     # Quote original
